@@ -1,10 +1,10 @@
-if (lme4:::testLevel() > 1 || .Platform$OS.type!="windows") {
+if (lme4:::testLevel() > 1 || .Platform$OS.type != "windows") {
     library("lme4")
     library("testthat")
 
     L <- load(system.file("testdata", "lme-tst-fits.rda",
                           package="lme4", mustWork=TRUE))
-
+    ## -> "fit_*" objects
 
     fm1 <- fit_sleepstudy_2
     c0  <- confint(fm1, method="Wald")
@@ -13,7 +13,7 @@ if (lme4:::testLevel() > 1 || .Platform$OS.type!="windows") {
     expect_equal(c(c0B),c(7.437592,13.496980),tolerance=1e-6)
     set.seed(101)
 
-    for (bt in c("norm","basic", "perc")) {
+    for (bt in c("norm", "basic", "perc")) {
         suppressWarnings(
             confint(fm1, method="boot", boot.type=bt, nsim=10,quiet=TRUE))
     }
@@ -22,9 +22,13 @@ if (lme4:::testLevel() > 1 || .Platform$OS.type!="windows") {
                      "should be one of")
     }
     if((testLevel <- lme4:::testLevel()) > 1) {
-        c1 <- confint(fm1,method="profile",parm=5:6)
+        pr1.56 <- profile(fm1, which = 5:6)
+        c1 <- confint(pr1.56, method="profile")
         expect_equal(c0[5:6,],c1,tolerance=2e-3)  ## expect Wald and profile _reasonably_ close
         print(c1,digits=3)
+        ##
+        c6 <- confint(pr1.56, "Days")
+        expect_equal(c1[2, , drop=FALSE], c6)
         c2  <- confint(fm1,method="boot",nsim=50,parm=5:6)
         ## expect_error(confint(fm1,method="boot",nsim=50,parm="Days"),
         ##  "must be specified as an integer")
