@@ -26,9 +26,10 @@ if (.Platform$OS.type != "windows") {
     ii <- sample(nrow(sleepstudy), 500, replace=TRUE)
     m2 <- lmer(Reaction ~ Days + (Days | Subject), sleepstudy[ii, ])
 
+    
     stopifnot(all.equal(diag(H),
-                        unn(lme4:::hatvalues.merMod(m)),  tol= 1e-14),
+                        unn(hatvalues(m)),  tol= 1e-14),
               all.equal(diag(bruteForceHat(m2)),
-                        unn(lme4:::hatvalues.merMod(m2)), tol= 1e-14)
+                        unn(hatvalues(m2)), tol= 1e-14)
               )
 } ## skip on windows (for speed)
