@@ -13,13 +13,9 @@ context("Errors and warnings from glmer")
 test_that("glmer", {
     expect_error(glmer(y ~ 1 + (1|block), data=dBc, family=binomial(link="cloglog")),
                  "Response is constant")
-    expect_warning(lmer(cbind(incidence, size - incidence) ~ period + (1 | herd),
-                              family = binomial, data = cbpp),
-                   "calling lmer with .*family.* is deprecated.*")
-    ## expect_equal(m1,m2)
-    expect_warning(glmer(cbind(incidence, size - incidence) ~ period + (1 | herd),
-                         family = binomial, data = cbpp, REML=TRUE),
-                   "extra argument.*REML")
+    expect_error(glmer(cbind(incidence, size - incidence) ~ period + (1 | herd),
+                       family = binomial, data = cbpp, REML=TRUE),
+                   "unused argument.*REML")
     expect_warning(glmer(Reaction ~ Days + (Days|Subject), sleepstudy),
                    "calling glmer.*family=gaussian.*deprecated")
     expect_warning(glmer(Reaction ~ Days + (Days|Subject), sleepstudy, family=gaussian),
